function v = vlsm_processargs(varargin)

% VLSM_PROCESSARGS  Evaluate variable-length lists of options.
%
% V = VLSM_PROCESSARGS(ARGS, POSSIBLEARG1, POSSIBLETYPE1, DEFAULT1,
%     POSSIBLEARG2, POSSIBLETYPE2, DEFAULT2, ...) sets up the structure V to
% contain all the POSSIBLEARGs. They are set to their value if they are found
% in ARGS, otherwise they are set to their DEFAULT. The POSSIBLETYPE
% arguments restrict the values: 's' for string, 'n' for numeric, 'b' for
% binary (0 or 1), or 'f' for free, i.e. anything.

% Copyright 2002 Stephen Wilson
%
% This file is part of VLSM, which is free software released under the terms
% of the GNU General Public Licence. Please see README.txt for details

if nargin < 1, error('Not enough input arguments.'); end

% parse
args = varargin{1};
argspecs = varargin(2:end);
possibleargs = argspecs(1:3:end);
argtypes = argspecs(2:3:end);
defaults = argspecs(3:3:end);

% set defaults
for i = 1:length(possibleargs)
  eval(['v.' possibleargs{i} ' = defaults{i};']);
end

% process args
i = 1;
while i <= length(args)
  nextarg = args{i};
  argidx = find(strcmp(nextarg, possibleargs));
  if ~isempty(argidx)
    if strcmp(argtypes{argidx}, 'done')
      error(['Repeated argument: ' nextarg]);
    else
      i = i + 1;
      if i <= length(args)
        nextval = args{i};
        eval(['v.' possibleargs{argidx} ' = nextval;']);

        % make sure the value we just found is legal
        if strcmp(argtypes{argidx}, 's') && ~isa(nextval, 'char')
          error(['A string value was expected for ' nextarg]);
        elseif strcmp(argtypes{argidx}, 'n') && ~isa(nextval, 'numeric')
          error(['A numeric value was expected for ' nextarg]);
        elseif strcmp(argtypes{argidx}, 'b')
          if isa(nextval, 'numeric') || isa(nextval, 'logical')
            if nextval ~= 0 && nextval ~= 1 && nextval ~= false && nextval ~= true
              error(['A binary value was expected for ' nextarg]);
            end
          else
            error(['A binary value was expected for ' nextarg]);
          end
        end

      else
        error(['No value for ' nextarg]);
      end
    end
    argtypes{argidx} = 'done'; % avoid repeats
  else
    error(['Unrecognized argument: ' nextarg]);
  end
  i = i + 1;
end
